pub enum RetainHandling {
AlwaysSend,
SendIfNotSubscribedBefore,
NeverSend,
}Expand description
Serverside retain handling configuration for a subscription.
Variants
AlwaysSend
Retained messages are always sent at the time of the subscribe.
SendIfNotSubscribedBefore
Retained messages are only sent if the subscription did not exist before.
NeverSend
Retained messages are never sent.