TopicReference

Enum TopicReference 

pub enum TopicReference<'t> {
    Name(TopicName<'t>),
    Alias(u16),
    Mapping(TopicName<'t>, u16),
}
The options for specifying which topic to publish to. Topic aliases only last for the duration of a single network connection and not necessarily until the session end.

Topic aliases must not be 0

Variants



Name(TopicName<'t>)

Publish to the inner topic name without creating an alias.



Alias(u16)

Publish to an already mapped topic alias. The alias must have been defined earlier in the network connection.



Mapping(TopicName<'t>, u16)

Create a new topic alias or replace an existing topic alias. The alias lasts until the end of the network connection.

Implementations

Source

impl<'t> TopicReference<'t>

pub fn as_borrowed(&'t self) -> Self