SessionExpiryInterval

Enum SessionExpiryInterval 

pub enum SessionExpiryInterval {
    EndOnDisconnect,
    NeverEnd,
    Seconds(u32),
}
The handling of a session after a disconnection.

Variants



EndOnDisconnect

The session ends the moment a DISCONNECT packet is sent or the network connection closes.



NeverEnd

The session is not ended under any circumstances.



Seconds(u32)

The session ends after this many seconds have passed after a DISCONNECT packet is sent or the network connection closes.