ClientConfig

Struct ClientConfig 

pub struct ClientConfig {
    pub session_expiry_interval: SessionExpiryInterval,
    pub maximum_accepted_remaining_length: u32,
}
Configuration of the client which must be upheld by the server.

Fields

session_expiry_interval: SessionExpiryInterval

The session expiry interval requested by the client. This field is used to determine whether a non-zero session expiry interval can be used when disconnecting. This value is configured when calling crate::client::Client::connect from the value in crate::client::options::ConnectOptions

maximum_accepted_remaining_length: u32

The maximum packet size the client is willing to accept transformed into the maximum value of the remaining length that is therefore accepted. This value is configured when calling crate::client::Client::connect from the value in crate::client::options::ConnectOptions