ReceiveMaximum

Struct ReceiveMaximum 

pub struct ReceiveMaximum(pub NonZero<u16>);
Maximum concurrent publications with a Quality of Service > 0.

Default is 65536 / u16::MAX and is used when no receive maximum is present. Can’t be zero.

Tuple Fields

0: NonZero<u16>