pub struct ServerConfig {
pub receive_maximum: ReceiveMaximum,
pub maximum_qos: QoS,
pub retain_supported: bool,
pub maximum_packet_size: MaximumPacketSize,
pub topic_alias_maximum: u16,
pub wildcard_subscription_supported: bool,
pub subscription_identifiers_supported: bool,
pub shared_subscription_supported: bool,
}Expand description
Configuration of the server which must be upheld by the client.
Fields
receive_maximum: ReceiveMaximumMaximum concurrent QoS 1 & 2 publications that the server is willing to accept.
maximum_qos: QoSMaximum supported QoS by the server.
retain_supported: boolRetained messages are supported by the server.
maximum_packet_size: MaximumPacketSizeMaximum packet size that the server is willing to accept.
topic_alias_maximum: u16Highest value of a topic alias the server is willing to accept. Equal to the number of distinct topic aliases the server supports.
wildcard_subscription_supported: boolServerside support for wildcard subscriptions.
subscription_identifiers_supported: boolServerside support for subscription identifiers.
Serverside support for shared subscriptions.