pub struct SharedConfig {
pub keep_alive: KeepAlive,
pub session_expiry_interval: SessionExpiryInterval,
}Expand description
Negotiated configuration valid for the duration of a connection.
Fields
keep_alive: KeepAliveThe negotiated KeepAlive interval in seconds allowed to expire between sending two packets without the connection being closed.
session_expiry_interval: SessionExpiryIntervalThe negotiated SessionExpiryInterval after the connection has been closed.