FixedHeader

Struct FixedHeader 

pub struct FixedHeader { /* private fields */ }
The fixed header of any MQTT Control Packet containing the packet type, flags and the remaining length.

Implementations

Source

impl FixedHeader

pub fn flags(&self) -> u8

Returns the flags of the FixedHeader. These are the lower 4 bits of the first byte. The type of the packet is masked away.

pub fn packet_type(&self) -> Result<PacketType, Reserved>

Returns the PacketType

Errors

Returns Reserved if the value of the packet type bits is reserved.