pub struct Session<const RECEIVE_MAXIMUM: usize, const SEND_MAXIMUM: usize> {
pub pending_client_publishes: Vec<InFlightPublish<CPublishFlightState>, SEND_MAXIMUM>,
pub pending_server_publishes: Vec<InFlightPublish<SPublishFlightState>, RECEIVE_MAXIMUM>,
}Expand description
Session-associated information
Client identifier is not stored here as it would lead to inconsistencies with the underyling allocation system.
Fields
pending_client_publishes: Vec<InFlightPublish<CPublishFlightState>, SEND_MAXIMUM>The currently in-flight outgoing publications.
pending_server_publishes: Vec<InFlightPublish<SPublishFlightState>, RECEIVE_MAXIMUM>The currently in-flight incoming publications.
Implementations
Sourceimpl<const RECEIVE_MAXIMUM: usize, const SEND_MAXIMUM: usize> Session<RECEIVE_MAXIMUM, SEND_MAXIMUM>
impl<const RECEIVE_MAXIMUM: usize, const SEND_MAXIMUM: usize> Session<RECEIVE_MAXIMUM, SEND_MAXIMUM>
Sourcepub fn is_used_cpublish_packet_identifier(
&self,
packet_identifier: PacketIdentifier,
) -> bool
pub fn is_used_cpublish_packet_identifier( &self, packet_identifier: PacketIdentifier, ) -> bool
Returns whether the packet identifier is currently in-flight in a client->server publication process.
Sourcepub fn is_used_spublish_packet_identifier(
&self,
packet_identifier: PacketIdentifier,
) -> bool
pub fn is_used_spublish_packet_identifier( &self, packet_identifier: PacketIdentifier, ) -> bool
Returns whether the packet identifier is currently in-flight in a server->client publication process.
Sourcepub fn cpublish_flight_state(
&self,
packet_identifier: PacketIdentifier,
) -> Option<CPublishFlightState>
pub fn cpublish_flight_state( &self, packet_identifier: PacketIdentifier, ) -> Option<CPublishFlightState>
Returns the state of the publication of the packet identifier if the packet identifier is in-flight in an outgoing publication.
Sourcepub fn spublish_flight_state(
&self,
packet_identifier: PacketIdentifier,
) -> Option<SPublishFlightState>
pub fn spublish_flight_state( &self, packet_identifier: PacketIdentifier, ) -> Option<SPublishFlightState>
Returns the state of the publication of the packet identifier if the packet identifier is in-flight in an incoming publication.
Sourcepub fn in_flight_cpublishes(&self) -> u16
pub fn in_flight_cpublishes(&self) -> u16
Returns the amount of currently in-flight outgoing publications.
Sourcepub fn in_flight_spublishes(&self) -> u16
pub fn in_flight_spublishes(&self) -> u16
Returns the amount of currently in-flight incoming publications.
Sourcepub fn cpublish_remaining_capacity(&self) -> u16
pub fn cpublish_remaining_capacity(&self) -> u16
Returns the amount of slots for outgoing publications.
Sourcepub fn spublish_remaining_capacity(&self) -> u16
pub fn spublish_remaining_capacity(&self) -> u16
Returns the amount of slots for incoming publications.