IdentifiedQoS

Enum IdentifiedQoS 

pub enum IdentifiedQoS {
    AtMostOnce,
    AtLeastOnce(PacketIdentifier),
    ExactlyOnce(PacketIdentifier),
}
MQTT’s Quality of Service with special reference to the PUBLISH packet which contains a packet identifier if its Quality of Service is greater than 0.

Variants



AtMostOnce

Quality of Service Level 0. PUBLISH packets do not contain a packet identifier.



AtLeastOnce(PacketIdentifier)

Quality of Service Level 1. PUBLISH packets contain the included packet identifier.



ExactlyOnce(PacketIdentifier)

Quality of Service Level 2. PUBLISH packets contain the included packet identifier.

Implementations

Source

impl IdentifiedQoS

pub const fn packet_identifier(&self) -> Option<PacketIdentifier>

Returns Some if QoS > 0 and therefore has to be identified, and None otherwise.