MqttStringError

Enum MqttStringError 

pub enum MqttStringError {
    Utf8Error(Utf8Error),
    NullCharacter,
    TooLargeToEncode,
}
Error returned when creating MqttString failed.

Variants



Utf8Error(Utf8Error)

The passed data is not valid UTF-8.



NullCharacter

The passed data contains at least one null character.



TooLargeToEncode

The passed data exceeds the max length of MqttString::MAX_LENGTH.