pub enum QoS {
AtMostOnce = 0,
AtLeastOnce = 1,
ExactlyOnce = 2,
}Expand description
MQTT’s Quality of Service
Variants
AtMostOnce = 0
Quality of Service Level 0. Publications with this level are only sent once.
AtLeastOnce = 1
Quality of Service Level 1. Publications with this level are sent until a PUBACK indicates that it was received.
ExactlyOnce = 2
Quality of Service Level 2. Publications with this level are followed by a handshake assuring it is received once.