pub struct TooLargeToEncode;Expand description
The error returned when types are larger than what is representable according to the specification.
VarByteInt: IfVarByteInt::MAX_ENCODABLEis exceeded, an error of this type is returned.MqttBinary: IfMqttBinary::MAX_LENGTHis exceeded, an error of this type is returned.