TopicName

Struct TopicName 

pub struct TopicName<'t>(/* private fields */);
A topic name string for that messages can be published on according to https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901241. Cannot contain wildcard characters.

Examples:

  • “sport/tennis/player1”
  • “sport/tennis/player1/ranking”
  • “sport/tennis/player1/score/wimbledon”

Implementations

Source

impl<'t> TopicName<'t>

pub fn new(string: MqttString<'t>) -> Option<Self>

Creates a new topic name while checking for correct syntax of the topic name string.

pub const fn new_unchecked(string: MqttString<'t>) -> Self

Creates a new topic name without checking for correct syntax of the topic name string.

Invariants

The syntax of the topic name is valid. For a fallible version, use TopicName::new

Panics

In debug builds, this function will panic if the syntax of string is incorrect.

pub const fn as_borrowed(&'t self) -> Self