VarByteInt

Struct VarByteInt 

pub struct VarByteInt(/* private fields */);
MQTT’s variable byte integer encoding. The value has to be less than VarByteInt::MAX_ENCODABLE (268_435_455). Exceeding this ultimately leads to panics or malformed packets.

Used for packet length and some properties.

Use its TryFrom (u32) and From (u16, u8) implementations to construct a value.

Implementations

Source

impl VarByteInt

pub const MAX_ENCODABLE: u32 = 268_435_455

The maximum encodable value using the variable byte integer encoding according to https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901011.

pub const fn new(value: u32) -> Option<Self>

Creates a variable byte integer by checking for the maximum value of VarByteInt::MAX_ENCODABLE. For a version accepting u16 and u8, use From::from.

pub const fn new_unchecked(value: u32) -> Self

Creates a variable byte integer without checking for the maximum value of VarByteInt::MAX_ENCODABLE. For a fallible version, use VarByteInt::new. For an infallible version accepting u16 and u8, use From::from.

Invariants

The value parameter must be less than or equal to VarByteInt::MAX_ENCODABLE.

Panics

Panics in debug builds if value exceeds VarByteInt::MAX_ENCODABLE.

pub const fn value(&self) -> u32

Returns the inner value.

pub const fn size(&self) -> usize

Returns Self::value as usize.