pub struct ConnectInfo<'i> {
pub session_present: bool,
pub client_identifier: MqttString<'i>,
pub response_information: Option<MqttString<'i>>,
pub server_reference: Option<MqttString<'i>>,
}Expand description
Information taken from a connection handshake the client does not have to store for correct operational behaviour and does not store for optimization purposes.
Does not include the reason code as it is always crate::types::ReasonCode::Success (0x00)
if this is returned.
Fields
session_present: boolIf set to true, a previous session is continued by the server for this connection.
client_identifier: MqttString<'i>The server can assign a different client identifier than the one in the CONNECT packet or must assign a client identifier if none was included in the CONNECT packet. This is the final client identifier value used for this session.
response_information: Option<MqttString<'i>>Response information used to create response topics.
server_reference: Option<MqttString<'i>>Another server which can be used.