DisconnectOptions

Struct DisconnectOptions 

pub struct DisconnectOptions {
    pub publish_will: bool,
    pub session_expiry_interval: Option<SessionExpiryInterval>,
}
Options for a disconnection to the server with a DISCONNECT packet.

Fields

publish_will: bool

If set to true, the server publishes the will message.

session_expiry_interval: Option<SessionExpiryInterval>

The session expiry interval property. Not allowed to be set to a non-zero value if the session expiry interval property in the CONNECT packet has been 0. This value overrides the session expiry interval negotiated in the handshake.

Implementations

Source

impl Options

pub const fn new() -> Self

Creates new disconnect options with will publication disabled and no session expiry interval.

pub const fn publish_will(self) -> Self

Sets the publish will flag to true.

pub const fn session_expiry_interval( self, interval: SessionExpiryInterval, ) -> Self

Sets the session expiry interval property.