pub enum MaximumPacketSize {
Unlimited,
Limit(NonZero<u32>),
}Expand description
Maximum packet size. Exceeding this is a protocol error.
Variants
Unlimited
There is no imposed limit on how large packets can be.
The technical limit is crate::types::VarByteInt::MAX_ENCODABLE + 5 (size of fixed header).
Limit(NonZero<u32>)
There is a limit on how large packets can be. The packet size is the value of its remaining length plus the size of the fixed header. A value of 0 is not allowed by the specification. A value less than 2 does not make sense because every MQTT packet contains a fixed header of at least 2 bytes.