pub enum CPublishFlightState {
AwaitingPuback,
AwaitingPubrec,
AwaitingPubcomp,
}Expand description
The state of an incomplete QoS 1 or 2 publication by the client.
Variants
AwaitingPuback
A QoS 1 PUBLISH packet has been sent.
The next step in the handshake is the server sending a PUBACK packet.
AwaitingPubrec
A QoS 2 PUBLISH packet has been sent.
The next step in the handshake is the server sending a PUBREC packet.
AwaitingPubcomp
A PUBREC packet has been received and responded to with a PUBREL packet. The last step in the handshake is the server sending a PUBCOMP packet.