pub enum SPublishFlightState {
AwaitingPubrel,
}Expand description
The state of an incomplete QoS 2 publication by the server.
Variants
AwaitingPubrel
A QoS 2 packet has been received and responded to with a PUBREC packet.
The next step in the handshake is the server sending a PUBREL packet.