Session

Struct Session 

pub struct Session<const RECEIVE_MAXIMUM: usize, const SEND_MAXIMUM: usize> {
    pub pending_client_publishes: Vec<InFlightPublish<CPublishFlightState>, SEND_MAXIMUM>,
    pub pending_server_publishes: Vec<InFlightPublish<SPublishFlightState>, RECEIVE_MAXIMUM>,
}
Session-associated information

Client identifier is not stored here as it would lead to inconsistencies with the underyling allocation system.

Fields

pending_client_publishes: Vec<InFlightPublish<CPublishFlightState>, SEND_MAXIMUM>

The currently in-flight outgoing publications.

pending_server_publishes: Vec<InFlightPublish<SPublishFlightState>, RECEIVE_MAXIMUM>

The currently in-flight incoming publications.

Implementations

Source

impl<const RECEIVE_MAXIMUM: usize, const SEND_MAXIMUM: usize> Session<RECEIVE_MAXIMUM, SEND_MAXIMUM>

pub fn is_used_cpublish_packet_identifier( &self, packet_identifier: PacketIdentifier, ) -> bool

Returns whether the packet identifier is currently in-flight in a client->server publication process.

pub fn is_used_spublish_packet_identifier( &self, packet_identifier: PacketIdentifier, ) -> bool

Returns whether the packet identifier is currently in-flight in a server->client publication process.

pub fn cpublish_flight_state( &self, packet_identifier: PacketIdentifier, ) -> Option<CPublishFlightState>

Returns the state of the publication of the packet identifier if the packet identifier is in-flight in an outgoing publication.

pub fn spublish_flight_state( &self, packet_identifier: PacketIdentifier, ) -> Option<SPublishFlightState>

Returns the state of the publication of the packet identifier if the packet identifier is in-flight in an incoming publication.

pub fn in_flight_cpublishes(&self) -> u16

Returns the amount of currently in-flight outgoing publications.

pub fn in_flight_spublishes(&self) -> u16

Returns the amount of currently in-flight incoming publications.

pub fn cpublish_remaining_capacity(&self) -> u16

Returns the amount of slots for outgoing publications.

pub fn spublish_remaining_capacity(&self) -> u16

Returns the amount of slots for incoming publications.