pub enum IdentifiedQoS {
AtMostOnce,
AtLeastOnce(PacketIdentifier),
ExactlyOnce(PacketIdentifier),
}Expand description
MQTT’s Quality of Service with special reference to the PUBLISH packet which contains a packet identifier if its Quality of Service is greater than 0.
Variants
AtMostOnce
Quality of Service Level 0. PUBLISH packets do not contain a packet identifier.
AtLeastOnce(PacketIdentifier)
Quality of Service Level 1. PUBLISH packets contain the included packet identifier.
ExactlyOnce(PacketIdentifier)
Quality of Service Level 2. PUBLISH packets contain the included packet identifier.
Implementations
Sourceimpl IdentifiedQoS
impl IdentifiedQoS
Sourcepub const fn packet_identifier(&self) -> Option<PacketIdentifier>
pub const fn packet_identifier(&self) -> Option<PacketIdentifier>